package Locale::CLDR::Transformations::Any::Interindic::Latin;
# This file auto generated from Data\common\transforms\InterIndic-Latin.xml
#	on Sun  4 Mar  1:00:40 pm GMT

use strict;
use warnings;
use version;

our $VERSION = version->declare('v0.32.0');

use v5.10.1;
use mro 'c3';
use utf8;
use if $^V ge v5.12.0, feature => 'unicode_strings';
use Types::Standard qw( Str Int HashRef ArrayRef CodeRef RegexpRef );
use Moo;

BEGIN {
	die "Transliteration requires Perl 5.18 or above"
		unless $^V ge v5.18.0;
}

no warnings 'experimental::regex_sets';
has 'transforms' => (
	is => 'ro',
	isa => ArrayRef,
	init_arg => undef,
	default => sub { [
		qr/(?^um:\G.)/,
		{
			type => 'transform',
			data => [
			],
		},
		{
			type => 'conversion',
			data => [
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(ṅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(n̄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(ṇ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(n),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(m),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(n),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ṁ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(ẏ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ẏ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ẏa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(ḻ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ḻ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ḻa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(ṉ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ṉ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ṉa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(ṉ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ṉ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ṉa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(qa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(q),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(q),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(qa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(ḵẖ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ḵẖ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ḵẖa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ḵẖ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ḵẖa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ġa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(ġ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ġ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ġa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(za),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(z),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(z),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(za),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(ṛh),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ṛh),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ṛha),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(ṛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ṛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ṛa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ṛa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(ṛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ṛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ṛa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(f),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(f),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(fa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(f),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(f),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(fa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(ṟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ṟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ṟa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(ḻ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ḻ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ḻa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(ḻ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ḻ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ḻa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(ẏ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ẏ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ẏa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(k'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(k),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(k),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ka),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(kh),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(kh),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(kha),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(g'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(g),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(g),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ga),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(gh),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(gh),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(gha),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(ṅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ṅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ṅa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(c'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(c),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(c),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ca),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(ch),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ch),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(cha),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(j'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(j),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(j),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ja),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(jh),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(jh),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(jha),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(ñ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ñ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ña),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ṭ'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(ṭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ṭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ṭa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(ṭh),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ṭh),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ṭha),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(ḍ'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(ḍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ḍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ḍa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(ḍh),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ḍh),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ḍha),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(ṇ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ṇ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ṇa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(t'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(t'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(t'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(t'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(t),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(t),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ta),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(th),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(th),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(tha),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(d'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(d'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(d'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(d'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(d),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(d),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(da),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(dh),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(dh),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(dha),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(n'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(n'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(n),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(n),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(na),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(p'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(p),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(p),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(pa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(ph),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ph),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(pha),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(b'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(b),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(b),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ba),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(bh),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(bh),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(bha),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(m'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(m),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(m),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ma),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(y),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(y),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ya),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(r'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(r),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(r),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ra),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ẇ'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(ẇ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ẇ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ẇa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ṟ'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(ṟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ṟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ṟa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(l'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(l),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(l),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(la),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ḷ'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(ḷ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ḷ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ḷa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(v),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(v),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(va),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(s'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(s'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(s'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(s'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(s),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(s),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(ś),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ś),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(śa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(sa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(ś),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ś),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(śa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(ṣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ṣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ṣa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(h),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(h),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ha),
					revisit => 0,
				},
				{
					before  => q((?:(?!(?:[\p{L}]|[̀-͌]))(?s:.))),
					after   => q(),
					replace => q(),
					result  => q(̔ā),
					revisit => 0,
				},
				{
					before  => q((?:(?!(?:[\p{L}]|[̀-͌]))(?s:.))),
					after   => q(),
					replace => q(),
					result  => q(̔ai),
					revisit => 0,
				},
				{
					before  => q((?:(?!(?:[\p{L}]|[̀-͌]))(?s:.))),
					after   => q(),
					replace => q(),
					result  => q(̔au),
					revisit => 0,
				},
				{
					before  => q((?:(?!(?:[\p{L}]|[̀-͌]))(?s:.))),
					after   => q(),
					replace => q(),
					result  => q(̔ī),
					revisit => 0,
				},
				{
					before  => q((?:(?!(?:[\p{L}]|[̀-͌]))(?s:.))),
					after   => q(),
					replace => q(),
					result  => q(̔i),
					revisit => 0,
				},
				{
					before  => q((?:(?!(?:[\p{L}]|[̀-͌]))(?s:.))),
					after   => q(),
					replace => q(),
					result  => q(̔ū),
					revisit => 0,
				},
				{
					before  => q((?:(?!(?:[\p{L}]|[̀-͌]))(?s:.))),
					after   => q(),
					replace => q(),
					result  => q(̔u),
					revisit => 0,
				},
				{
					before  => q((?:(?!(?:[\p{L}]|[̀-͌]))(?s:.))),
					after   => q(),
					replace => q(),
					result  => q(̔r̥̄),
					revisit => 0,
				},
				{
					before  => q((?:(?!(?:[\p{L}]|[̀-͌]))(?s:.))),
					after   => q(),
					replace => q(),
					result  => q(̔r̥),
					revisit => 0,
				},
				{
					before  => q((?:(?!(?:[\p{L}]|[̀-͌]))(?s:.))),
					after   => q(),
					replace => q(),
					result  => q(̔l̥̄),
					revisit => 0,
				},
				{
					before  => q((?:(?!(?:[\p{L}]|[̀-͌]))(?s:.))),
					after   => q(),
					replace => q(),
					result  => q(̔l̥),
					revisit => 0,
				},
				{
					before  => q((?:(?!(?:[\p{L}]|[̀-͌]))(?s:.))),
					after   => q(),
					replace => q(),
					result  => q(̔ē),
					revisit => 0,
				},
				{
					before  => q((?:(?!(?:[\p{L}]|[̀-͌]))(?s:.))),
					after   => q(),
					replace => q(),
					result  => q(̔ō),
					revisit => 0,
				},
				{
					before  => q((?:(?!(?:[\p{L}]|[̀-͌]))(?s:.))),
					after   => q(),
					replace => q(),
					result  => q(̔ĕ),
					revisit => 0,
				},
				{
					before  => q((?:(?!(?:[\p{L}]|[̀-͌]))(?s:.))),
					after   => q(),
					replace => q(),
					result  => q(̔ŏ),
					revisit => 0,
				},
				{
					before  => q((?:(?!(?:[\p{L}]|[̀-͌]))(?s:.))),
					after   => q(),
					replace => q(),
					result  => q(̔e),
					revisit => 0,
				},
				{
					before  => q((?:(?!(?:[\p{L}]|[̀-͌]))(?s:.))),
					after   => q(),
					replace => q(),
					result  => q(̔o),
					revisit => 0,
				},
				{
					before  => q((?:(?!(?:[\p{L}]|[̀-͌]))(?s:.))),
					after   => q(),
					replace => q(),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q((?:(?!(?:[\p{L}]|[̀-͌]))(?s:.))),
					after   => q(),
					replace => q(),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ā),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(au),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ī),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(i),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ū),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(u),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(r̥̄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(r̥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(l̥̄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(l̥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ē),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ō),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ĕ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ŏ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(e),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(o),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(ā̔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(ai̔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(au̔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(ī̔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(i̔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(ū̔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(u̔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(r̥̄̔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(r̥̔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(l̥̄̔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(l̥̔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(ē̔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(ō̔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(a̔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(ĕ̔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(ŏ̔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(e̔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(o̔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q('om̔),
					revisit => 0,
				},
				{
					before  => q([aeiour̥̄̆]),
					after   => q(),
					replace => q(),
					result  => q('ā),
					revisit => 0,
				},
				{
					before  => q([aeiour̥̄̆]),
					after   => q(),
					replace => q(),
					result  => q('ai),
					revisit => 0,
				},
				{
					before  => q([aeiour̥̄̆]),
					after   => q(),
					replace => q(),
					result  => q('au),
					revisit => 0,
				},
				{
					before  => q([aeiour̥̄̆]),
					after   => q(),
					replace => q(),
					result  => q('ī),
					revisit => 0,
				},
				{
					before  => q([aeiour̥̄̆]),
					after   => q(),
					replace => q(),
					result  => q('i),
					revisit => 0,
				},
				{
					before  => q([aeiour̥̄̆]),
					after   => q(),
					replace => q(),
					result  => q('ū),
					revisit => 0,
				},
				{
					before  => q([aeiour̥̄̆]),
					after   => q(),
					replace => q(),
					result  => q('u),
					revisit => 0,
				},
				{
					before  => q([aeiour̥̄̆]),
					after   => q(),
					replace => q(),
					result  => q('r̥̄),
					revisit => 0,
				},
				{
					before  => q([aeiour̥̄̆]),
					after   => q(),
					replace => q(),
					result  => q('r̥),
					revisit => 0,
				},
				{
					before  => q([aeiour̥̄̆]),
					after   => q(),
					replace => q(),
					result  => q('l̥̄),
					revisit => 0,
				},
				{
					before  => q([aeiour̥̄̆]),
					after   => q(),
					replace => q(),
					result  => q('l̥),
					revisit => 0,
				},
				{
					before  => q([aeiour̥̄̆]),
					after   => q(),
					replace => q(),
					result  => q('ē),
					revisit => 0,
				},
				{
					before  => q([aeiour̥̄̆]),
					after   => q(),
					replace => q(),
					result  => q('ō),
					revisit => 0,
				},
				{
					before  => q([aeiour̥̄̆]),
					after   => q(),
					replace => q(),
					result  => q('a),
					revisit => 0,
				},
				{
					before  => q([aeiour̥̄̆]),
					after   => q(),
					replace => q(),
					result  => q('ĕ),
					revisit => 0,
				},
				{
					before  => q([aeiour̥̄̆]),
					after   => q(),
					replace => q(),
					result  => q('ŏ),
					revisit => 0,
				},
				{
					before  => q([aeiour̥̄̆]),
					after   => q(),
					replace => q(),
					result  => q('e),
					revisit => 0,
				},
				{
					before  => q([aeiour̥̄̆]),
					after   => q(),
					replace => q(),
					result  => q('o),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ā),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(au),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ī),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(i),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ū),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(u),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(r̥̄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(r̥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(l̥̄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(l̥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ē),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ō),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ĕ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ŏ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(e),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(o),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q('om),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(̕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(̃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(m̐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ḥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(2),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(3),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(4),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(5),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(6),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(7),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(8),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(9),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ʔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ṯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(ra),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(r),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ra),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(ra),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(r),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ra),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(),
					revisit => 0,
				},
			]
		},
	] },
);

no Moo;

1;

# vim: tabstop=4
