package Locale::CLDR::Transformations::Any::Halfwidth::Fullwidth;
# This file auto generated from Data\common\transforms\Fullwidth-Halfwidth.xml
#	on Sun  4 Mar  1:00:39 pm GMT

use strict;
use warnings;
use version;

our $VERSION = version->declare('v0.32.0');

use v5.10.1;
use mro 'c3';
use utf8;
use if $^V ge v5.12.0, feature => 'unicode_strings';
use Types::Standard qw( Str Int HashRef ArrayRef CodeRef RegexpRef );
use Moo;

BEGIN {
	die "Transliteration requires Perl 5.18 or above"
		unless $^V ge v5.18.0;
}

no warnings 'experimental::regex_sets';
has 'transforms' => (
	is => 'ro',
	isa => ArrayRef,
	init_arg => undef,
	default => sub { [
		qr/(?^um:\G.)/,
		{
			type => 'transform',
			data => [
			],
		},
		{
			type => 'conversion',
			data => [
				{
					before  => q(),
					after   => q(),
					replace => q(￮),
					result  => q(○),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(￭),
					result  => q(■),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(￬),
					result  => q(↓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(￪),
					result  => q(↑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(￨),
					result  => q(│),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(₩),
					result  => q(￦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(￥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(￤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(\u3000),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(￣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(￢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(￡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(￠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ￜ),
					result  => q(ᅵ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ￛ),
					result  => q(ᅴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ￚ),
					result  => q(ᅳ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ￗ),
					result  => q(ᅲ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ￖ),
					result  => q(ᅱ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ￕ),
					result  => q(ᅰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ￔ),
					result  => q(ᅯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ￓ),
					result  => q(ᅮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ￒ),
					result  => q(ᅭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ￏ),
					result  => q(ᅬ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ￎ),
					result  => q(ᅫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ￍ),
					result  => q(ᅪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ￌ),
					result  => q(ᅩ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ￋ),
					result  => q(ᅨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ￊ),
					result  => q(ᅧ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ￇ),
					result  => q(ᅦ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ￆ),
					result  => q(ᅥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ￅ),
					result  => q(ᅤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ￄ),
					result  => q(ᅣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ￃ),
					result  => q(ᅢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ￂ),
					result  => q(ᅡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾾ),
					result  => q(ᄒ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾽ),
					result  => q(ᄑ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾼ),
					result  => q(ᄐ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾻ),
					result  => q(ᄏ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾺ),
					result  => q(ᄎ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾹ),
					result  => q(ᄍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾸ),
					result  => q(ᄌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾷ),
					result  => q(ᄋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾶ),
					result  => q(ᄊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾵ),
					result  => q(ᄉ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾴ),
					result  => q(ᄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾳ),
					result  => q(ᄈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾲ),
					result  => q(ᄇ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾱ),
					result  => q(ᄆ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾰ),
					result  => q(ᄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾯ),
					result  => q(ᆵ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾮ),
					result  => q(ᆴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾭ),
					result  => q(ᆳ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾬ),
					result  => q(ᆲ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾫ),
					result  => q(ᆱ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾪ),
					result  => q(ᆰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾩ),
					result  => q(ᄅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾨ),
					result  => q(ᄄ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾧ),
					result  => q(ᄃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾦ),
					result  => q(ᆭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾥ),
					result  => q(ᆬ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾤ),
					result  => q(ᄂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾣ),
					result  => q(ᆪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾢ),
					result  => q(ᄁ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾡ),
					result  => q(ᄀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾠ),
					result  => q(\u1160),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾟ),
					result  => q(゚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾞ),
					result  => q(゙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾝ),
					result  => q(ン),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾜ),
					result  => q(ワ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾛ),
					result  => q(ロ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾚ),
					result  => q(レ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾙ),
					result  => q(ル),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾘ),
					result  => q(リ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾗ),
					result  => q(ラ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾖ),
					result  => q(ヨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾕ),
					result  => q(ユ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾔ),
					result  => q(ヤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾓ),
					result  => q(モ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾒ),
					result  => q(メ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾑ),
					result  => q(ム),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾐ),
					result  => q(ミ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾏ),
					result  => q(マ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾎ),
					result  => q(ホ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾍ),
					result  => q(ヘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾌ),
					result  => q(フ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾋ),
					result  => q(ヒ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾊ),
					result  => q(ハ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾉ),
					result  => q(ノ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾈ),
					result  => q(ネ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾇ),
					result  => q(ヌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾆ),
					result  => q(ニ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾅ),
					result  => q(ナ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾄ),
					result  => q(ト),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾃ),
					result  => q(テ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾂ),
					result  => q(ツ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾁ),
					result  => q(チ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾀ),
					result  => q(タ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｿ),
					result  => q(ソ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｾ),
					result  => q(セ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｽ),
					result  => q(ス),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｼ),
					result  => q(シ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｻ),
					result  => q(サ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｺ),
					result  => q(コ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｹ),
					result  => q(ケ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｸ),
					result  => q(ク),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｷ),
					result  => q(キ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｶ),
					result  => q(カ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｵ),
					result  => q(オ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｴ),
					result  => q(エ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｳ),
					result  => q(ウ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｲ),
					result  => q(イ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｱ),
					result  => q(ア),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｰ),
					result  => q(ー),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｯ),
					result  => q(ッ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｮ),
					result  => q(ョ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｭ),
					result  => q(ュ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｬ),
					result  => q(ャ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｫ),
					result  => q(ォ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｪ),
					result  => q(ェ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｩ),
					result  => q(ゥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｨ),
					result  => q(ィ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｧ),
					result  => q(ァ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｦ),
					result  => q(ヲ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(･),
					result  => q(・),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(､),
					result  => q(、),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(｣),
					result  => q(」),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(｢),
					result  => q(「),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(｡),
					result  => q(。),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(～),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(｝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(｜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(｛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(z),
					result  => q(ｚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(y),
					result  => q(ｙ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(x),
					result  => q(ｘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(w),
					result  => q(ｗ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(v),
					result  => q(ｖ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(u),
					result  => q(ｕ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(t),
					result  => q(ｔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(s),
					result  => q(ｓ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(r),
					result  => q(ｒ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(q),
					result  => q(ｑ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(p),
					result  => q(ｐ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(o),
					result  => q(ｏ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(n),
					result  => q(ｎ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(m),
					result  => q(ｍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(l),
					result  => q(ｌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(k),
					result  => q(ｋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(j),
					result  => q(ｊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(i),
					result  => q(ｉ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(h),
					result  => q(ｈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(g),
					result  => q(ｇ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(f),
					result  => q(ｆ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(e),
					result  => q(ｅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(d),
					result  => q(ｄ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(c),
					result  => q(ｃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(b),
					result  => q(ｂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(a),
					result  => q(ａ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(｀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(＿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(＾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(］),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(［),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Z),
					result  => q(Ｚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Y),
					result  => q(Ｙ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(X),
					result  => q(Ｘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(W),
					result  => q(Ｗ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(V),
					result  => q(Ｖ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(U),
					result  => q(Ｕ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(T),
					result  => q(Ｔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(S),
					result  => q(Ｓ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(R),
					result  => q(Ｒ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Q),
					result  => q(Ｑ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(P),
					result  => q(Ｐ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(O),
					result  => q(Ｏ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(N),
					result  => q(Ｎ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(M),
					result  => q(Ｍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(L),
					result  => q(Ｌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(K),
					result  => q(Ｋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(J),
					result  => q(Ｊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(I),
					result  => q(Ｉ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(H),
					result  => q(Ｈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(G),
					result  => q(Ｇ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(F),
					result  => q(Ｆ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(E),
					result  => q(Ｅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(D),
					result  => q(Ｄ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(C),
					result  => q(Ｃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(B),
					result  => q(Ｂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(A),
					result  => q(Ａ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(＠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(？),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(＞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(＝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(＜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(；),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(：),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(９),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(８),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(７),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(６),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(５),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(４),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(３),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(２),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(１),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(０),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(／),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(．),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(－),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(，),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(＋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(＊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(）),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(（),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q('),
					result  => q(＇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(＆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(％),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(＄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(＃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(＂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(！),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｦﾞ),
					result  => q(ヺ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾜﾞ),
					result  => q(ヷ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｳﾞ),
					result  => q(ヴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾎﾟ),
					result  => q(ポ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾎﾞ),
					result  => q(ボ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾍﾟ),
					result  => q(ペ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾍﾞ),
					result  => q(ベ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾌﾟ),
					result  => q(プ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾌﾞ),
					result  => q(ブ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾋﾟ),
					result  => q(ピ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾋﾞ),
					result  => q(ビ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾊﾟ),
					result  => q(パ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾊﾞ),
					result  => q(バ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾄﾞ),
					result  => q(ド),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾃﾞ),
					result  => q(デ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾂﾞ),
					result  => q(ヅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾁﾞ),
					result  => q(ヂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ﾀﾞ),
					result  => q(ダ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｿﾞ),
					result  => q(ゾ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｾﾞ),
					result  => q(ゼ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｽﾞ),
					result  => q(ズ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｼﾞ),
					result  => q(ジ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｻﾞ),
					result  => q(ザ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｺﾞ),
					result  => q(ゴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｹﾞ),
					result  => q(ゲ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｸﾞ),
					result  => q(グ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｷﾞ),
					result  => q(ギ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｶﾞ),
					result  => q(ガ),
					revisit => 0,
				},
			]
		},
	] },
);

no Moo;

1;

# vim: tabstop=4
