package Locale::CLDR::Transformations::Any::Latn::Armn;
# This file auto generated from Data\common\transforms\Latin-Armenian.xml
#	on Sun  4 Mar  1:00:41 pm GMT

use strict;
use warnings;
use version;

our $VERSION = version->declare('v0.32.0');

use v5.10.1;
use mro 'c3';
use utf8;
use if $^V ge v5.12.0, feature => 'unicode_strings';
use Types::Standard qw( Str Int HashRef ArrayRef CodeRef RegexpRef );
use Moo;

BEGIN {
	die "Transliteration requires Perl 5.18 or above"
		unless $^V ge v5.18.0;
}

no warnings 'experimental::regex_sets';
has 'transforms' => (
	is => 'ro',
	isa => ArrayRef,
	init_arg => undef,
	default => sub { [
		qr/(?^um:\G.)/,
		{
			type => 'transform',
			data => [
				{
					from => q(Any),
					to => q(NFD),
				},
			],
		},
		{
			type => 'conversion',
			data => [
				{
					before  => q(),
					after   => q(),
					replace => q(ev),
					result  => q(և),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(tʻ),
					result  => q(թ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(čʻ),
					result  => q(չ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(cʻ),
					result  => q(ց),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pʻ),
					result  => q(փ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kʻ),
					result  => q(ք),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(u),
					result  => q(ու),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(a),
					result  => q(ա),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(b),
					result  => q(բ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(g),
					result  => q(գ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(d),
					result  => q(դ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(e),
					result  => q(ե),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(z),
					result  => q(զ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ē),
					result  => q(է),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ə),
					result  => q(ը),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ž),
					result  => q(ժ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(i),
					result  => q(ի),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(l),
					result  => q(լ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(x),
					result  => q(խ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(c),
					result  => q(ծ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(k),
					result  => q(կ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(h),
					result  => q(հ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(j),
					result  => q(ձ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ġ),
					result  => q(ղ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(č),
					result  => q(ճ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(m),
					result  => q(մ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(y),
					result  => q(յ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(n),
					result  => q(ն),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(š),
					result  => q(շ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(o),
					result  => q(ո),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(p),
					result  => q(պ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ǰ),
					result  => q(ջ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ṙ),
					result  => q(ռ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(s),
					result  => q(ս),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(v),
					result  => q(վ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(t),
					result  => q(տ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(r),
					result  => q(ր),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(w),
					result  => q(ւ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ō),
					result  => q(օ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(f),
					result  => q(ֆ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(U),
					result  => q(ՈՒ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(EV),
					result  => q(ԵՒ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(J̌),
					result  => q(Ջ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Pʻ),
					result  => q(Փ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Kʻ),
					result  => q(Ք),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Tʻ),
					result  => q(Թ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Čʻ),
					result  => q(Չ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Cʻ),
					result  => q(Ց),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(A),
					result  => q(Ա),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(B),
					result  => q(Բ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(G),
					result  => q(Գ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(D),
					result  => q(Դ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(E),
					result  => q(Ե),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Z),
					result  => q(Զ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ē),
					result  => q(Է),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ə),
					result  => q(Ը),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ž),
					result  => q(Ժ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(I),
					result  => q(Ի),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(L),
					result  => q(Լ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(X),
					result  => q(Խ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(C),
					result  => q(Ծ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(K),
					result  => q(Կ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(H),
					result  => q(Հ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(J),
					result  => q(Ձ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ġ),
					result  => q(Ղ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Č),
					result  => q(Ճ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(M),
					result  => q(Մ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Y),
					result  => q(Յ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(N),
					result  => q(Ն),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Š),
					result  => q(Շ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(O),
					result  => q(Ո),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(P),
					result  => q(Պ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ṙ),
					result  => q(Ռ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(S),
					result  => q(Ս),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(V),
					result  => q(Վ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(T),
					result  => q(Տ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(R),
					result  => q(Ր),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(W),
					result  => q(Ւ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ō),
					result  => q(Օ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(F),
					result  => q(Ֆ),
					revisit => 0,
				},
			],
		},
		{
			type => 'transform',
			data => [
				{
					from => q(Any),
					to => q(NFC),
				},
			]
		},
	] },
);

no Moo;

1;

# vim: tabstop=4
