package Locale::CLDR::Transformations::Any::Conjoiningjamo::Latin;
# This file auto generated from Data\common\transforms\Latin-ConjoiningJamo.xml
#	on Sun  4 Mar  1:00:41 pm GMT

use strict;
use warnings;
use version;

our $VERSION = version->declare('v0.32.0');

use v5.10.1;
use mro 'c3';
use utf8;
use if $^V ge v5.12.0, feature => 'unicode_strings';
use Types::Standard qw( Str Int HashRef ArrayRef CodeRef RegexpRef );
use Moo;

BEGIN {
	die "Transliteration requires Perl 5.18 or above"
		unless $^V ge v5.18.0;
}

no warnings 'experimental::regex_sets';
has 'transforms' => (
	is => 'ro',
	isa => ArrayRef,
	init_arg => undef,
	default => sub { [
		qr/(?^um:\G.)/,
		{
			type => 'transform',
			data => [
			],
		},
		{
			type => 'conversion',
			data => [
				{
					before  => q(),
					after   => q(),
					replace => q(ᄋ),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᅲ),
					result  => q(yu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᅭ),
					result  => q(yo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᅨ),
					result  => q(ye),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᅧ),
					result  => q(yeo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᅣ),
					result  => q(ya),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᅤ),
					result  => q(yae),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᅱ),
					result  => q(wi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᅰ),
					result  => q(we),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᅯ),
					result  => q(wo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᅪ),
					result  => q(wa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᅫ),
					result  => q(wae),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᅮ),
					result  => q(u),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᅴ),
					result  => q(ui),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᅩ),
					result  => q(o),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᅬ),
					result  => q(oe),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᅵ),
					result  => q(i),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᅦ),
					result  => q(e),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᅳ),
					result  => q(eu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᅥ),
					result  => q(eo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᅡ),
					result  => q(a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᅢ),
					result  => q(ae),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᄒ),
					result  => q(h),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᄑ),
					result  => q(p),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᄐ),
					result  => q(t),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᄏ),
					result  => q(k),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᄎ),
					result  => q(ch),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᄌ),
					result  => q(j),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᄍ),
					result  => q(jj),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᄉ),
					result  => q(s),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᄊ),
					result  => q(ss),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᄇ),
					result  => q(b),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᄈ),
					result  => q(pp),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᄆ),
					result  => q(m),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᄅ),
					result  => q(l),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᄃ),
					result  => q(d),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᄄ),
					result  => q(tt),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᄂ),
					result  => q(n),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᄀ),
					result  => q(g),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᄁ),
					result  => q(kk),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᇀ),
					result  => q(t),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᆺ),
					result  => q(s),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᆻ),
					result  => q(ss),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᇁ),
					result  => q(p),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᆫ),
					result  => q(n),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᆬ),
					result  => q(nj),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᆭ),
					result  => q(nh),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᆼ),
					result  => q(ng),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᆷ),
					result  => q(m),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᆯ),
					result  => q(l),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᆴ),
					result  => q(lt),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᆳ),
					result  => q(ls),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᆵ),
					result  => q(lp),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᆱ),
					result  => q(lm),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᆶ),
					result  => q(lh),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᆲ),
					result  => q(lb),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᆿ),
					result  => q(k),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᆽ),
					result  => q(j),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᇂ),
					result  => q(h),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᆨ),
					result  => q(g),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᆪ),
					result  => q(gs),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᆩ),
					result  => q(kk),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᆮ),
					result  => q(d),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᆾ),
					result  => q(ch),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᆸ),
					result  => q(b),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᆹ),
					result  => q(bs),
					revisit => 0,
				},
				{
					before  => q([aeiou]c),
					after   => q([ᄒ]),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q([aeiou]t),
					after   => q(ᄐ),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q([aeiou]p),
					after   => q(ᄑ),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q([aeiou]k),
					after   => q([ᄁᄏ]),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q([aeiou]lt),
					after   => q([ᄐ]),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q([aeiou]lp),
					after   => q([ᄑ]),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q([aeiou]nj),
					after   => q([ᄌᄍ]),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q([aeiou]ng),
					after   => q([ᄀ]),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q([aeiou]ls),
					after   => q([ᄉᄊ]),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q([aeiou]lg),
					after   => q([ᄀ]),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q([aeiou]lb),
					after   => q([ᄇ]),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q([aeiou]gs),
					after   => q([ᄉᄊ]),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q([aeiou]bs),
					after   => q([ᄉᄊ]),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q([aeiou]s),
					after   => q(ᄉ[ᅡ-ᅵ]),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q([aeiou]k),
					after   => q(ᄏ[ᅡ-ᅵ]),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q([aeiou]j),
					after   => q(ᄌ[ᅡ-ᅵ]),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q([aeiou]ch),
					after   => q(ᄋ[ᅡ-ᅵ]),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q([aeiou]ss),
					after   => q(ᄋ[ᅡ-ᅵ]),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q([aeiou]nj),
					after   => q(ᄋ[ᅡ-ᅵ]),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q([aeiou]nh),
					after   => q(ᄋ[ᅡ-ᅵ]),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q([aeiou]ng),
					after   => q(ᄋ[ᅡ-ᅵ]),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q([aeiou]lt),
					after   => q(ᄋ[ᅡ-ᅵ]),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q([aeiou]ls),
					after   => q(ᄋ[ᅡ-ᅵ]),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q([aeiou]lp),
					after   => q(ᄋ[ᅡ-ᅵ]),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q([aeiou]lm),
					after   => q(ᄋ[ᅡ-ᅵ]),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q([aeiou]lh),
					after   => q(ᄋ[ᅡ-ᅵ]),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q([aeiou]lg),
					after   => q(ᄋ[ᅡ-ᅵ]),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q([aeiou]lb),
					after   => q(ᄋ[ᅡ-ᅵ]),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q([aeiou]gs),
					after   => q(ᄋ[ᅡ-ᅵ]),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q([aeiou]kk),
					after   => q(ᄋ[ᅡ-ᅵ]),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q([aeiou]bs),
					after   => q(ᄋ[ᅡ-ᅵ]),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q([aeiou]l),
					after   => q(ᄋ[ᅡ-ᅵ]),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q([aeiou]t),
					after   => q(ᄋ[ᅡ-ᅵ]),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q([aeiou]s),
					after   => q(ᄋ[ᅡ-ᅵ]),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q([aeiou]p),
					after   => q(ᄋ[ᅡ-ᅵ]),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q([aeiou]n),
					after   => q(ᄋ[ᅡ-ᅵ]),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q([aeiou]m),
					after   => q(ᄋ[ᅡ-ᅵ]),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q([aeiou]k),
					after   => q(ᄋ[ᅡ-ᅵ]),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q([aeiou]j),
					after   => q(ᄋ[ᅡ-ᅵ]),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q([aeiou]h),
					after   => q(ᄋ[ᅡ-ᅵ]),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q([aeiou]g),
					after   => q(ᄋ[ᅡ-ᅵ]),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q([aeiou]d),
					after   => q(ᄋ[ᅡ-ᅵ]),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q([aeiou]b),
					after   => q(ᄋ[ᅡ-ᅵ]),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q((?:(?![aeiouwy])(?s:.))[wy]a),
					after   => q(ᄋ[ᅦᅥᅳ]),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q((?:(?![aeiouwy])(?s:.))[oa]),
					after   => q(ᄋ[ᅦᅥᅳ]),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q((?:(?![aeiouwy])(?s:.))e),
					after   => q(ᄋ[ᅩᅬᅮ]),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q((?:(?![aeiouwy])(?s:.))[y]e),
					after   => q(ᄋ[ᅩᅬ]),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q([^y]u),
					after   => q([ᅵ]),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q([^ey]o),
					after   => q([ᅦᅥᅳ]),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q([^aowy]e),
					after   => q([ᅮᅴ]),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q([^aow]e),
					after   => q([ᅩᅬ]),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q(a),
					after   => q([ᅦᅥᅳ]),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q([aeiou]s),
					after   => q(ᄊ),
					replace => q(),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\-),
					result  => q(\-\-),
					revisit => 0,
				},
			]
		},
	] },
);

no Moo;

1;

# vim: tabstop=4
