package Locale::CLDR::Transformations::Any::Latin::Interindic;
# This file auto generated from Data\common\transforms\Latin-InterIndic.xml
#	on Sun  4 Mar  1:00:41 pm GMT

use strict;
use warnings;
use version;

our $VERSION = version->declare('v0.32.0');

use v5.10.1;
use mro 'c3';
use utf8;
use if $^V ge v5.12.0, feature => 'unicode_strings';
use Types::Standard qw( Str Int HashRef ArrayRef CodeRef RegexpRef );
use Moo;

BEGIN {
	die "Transliteration requires Perl 5.18 or above"
		unless $^V ge v5.18.0;
}

no warnings 'experimental::regex_sets';
has 'transforms' => (
	is => 'ro',
	isa => ArrayRef,
	init_arg => undef,
	default => sub { [
		qr/(?^um:\G.)/,
		{
			type => 'transform',
			data => [
			],
		},
		{
			type => 'conversion',
			data => [
				{
					before  => q(),
					after   => q(),
					replace => q(̕),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(̃),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(m̐),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḥ),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(x),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(̔ā),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(̔ai),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(̔au),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(̔ii),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(̔ī),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(̔i),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(̔ū),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(̔u),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(̔r̥̄),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(̔r̥),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(̔l̥̄),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(̔lh),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(̔l̥),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(̔ē),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(̔ō),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(̔a),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(̔ĕ),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(̔ŏ),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(̔e),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(̔o),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q((?:[-]|[bcdfghjklmnpqrstvwxyz]|[क-ह]|[ক-হ]|[ਕ-ਹ]|[ક-હ]|[କ-ହ]|[க-ஹ]|[క-హ]|[ಕ-ಹ]|[ക-ഹ])),
					after   => q(),
					replace => q(ā),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q((?:[-]|[bcdfghjklmnpqrstvwxyz]|[क-ह]|[ক-হ]|[ਕ-ਹ]|[ક-હ]|[କ-ହ]|[க-ஹ]|[క-హ]|[ಕ-ಹ]|[ക-ഹ])),
					after   => q(),
					replace => q(ai),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q((?:[-]|[bcdfghjklmnpqrstvwxyz]|[क-ह]|[ক-হ]|[ਕ-ਹ]|[ક-હ]|[କ-ହ]|[க-ஹ]|[క-హ]|[ಕ-ಹ]|[ക-ഹ])),
					after   => q(),
					replace => q(au),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q((?:[-]|[bcdfghjklmnpqrstvwxyz]|[क-ह]|[ক-হ]|[ਕ-ਹ]|[ક-હ]|[କ-ହ]|[க-ஹ]|[క-హ]|[ಕ-ಹ]|[ക-ഹ])),
					after   => q(),
					replace => q(ii),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q((?:[-]|[bcdfghjklmnpqrstvwxyz]|[क-ह]|[ক-হ]|[ਕ-ਹ]|[ક-હ]|[କ-ହ]|[க-ஹ]|[క-హ]|[ಕ-ಹ]|[ക-ഹ])),
					after   => q(),
					replace => q(ī),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q((?:[-]|[bcdfghjklmnpqrstvwxyz]|[क-ह]|[ক-হ]|[ਕ-ਹ]|[ક-હ]|[କ-ହ]|[க-ஹ]|[క-హ]|[ಕ-ಹ]|[ക-ഹ])),
					after   => q(),
					replace => q(i),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q((?:[-]|[bcdfghjklmnpqrstvwxyz]|[क-ह]|[ক-হ]|[ਕ-ਹ]|[ક-હ]|[କ-ହ]|[க-ஹ]|[క-హ]|[ಕ-ಹ]|[ക-ഹ])),
					after   => q(),
					replace => q(ū),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q((?:[-]|[bcdfghjklmnpqrstvwxyz]|[क-ह]|[ক-হ]|[ਕ-ਹ]|[ક-હ]|[କ-ହ]|[க-ஹ]|[క-హ]|[ಕ-ಹ]|[ക-ഹ])),
					after   => q(),
					replace => q(u),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q((?:[-]|[bcdfghjklmnpqrstvwxyz]|[क-ह]|[ক-হ]|[ਕ-ਹ]|[ક-હ]|[କ-ହ]|[க-ஹ]|[క-హ]|[ಕ-ಹ]|[ക-ഹ])),
					after   => q(),
					replace => q(r̥̄),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q((?:[-]|[bcdfghjklmnpqrstvwxyz]|[क-ह]|[ক-হ]|[ਕ-ਹ]|[ક-હ]|[କ-ହ]|[க-ஹ]|[క-హ]|[ಕ-ಹ]|[ക-ഹ])),
					after   => q(),
					replace => q(r̥a),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q((?:[-]|[bcdfghjklmnpqrstvwxyz]|[क-ह]|[ক-হ]|[ਕ-ਹ]|[ક-હ]|[କ-ହ]|[க-ஹ]|[క-హ]|[ಕ-ಹ]|[ക-ഹ])),
					after   => q(),
					replace => q(r̥),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q((?:[-]|[bcdfghjklmnpqrstvwxyz]|[क-ह]|[ক-হ]|[ਕ-ਹ]|[ક-હ]|[କ-ହ]|[க-ஹ]|[క-హ]|[ಕ-ಹ]|[ക-ഹ])),
					after   => q(),
					replace => q(l̥̄),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q((?:[-]|[bcdfghjklmnpqrstvwxyz]|[क-ह]|[ক-হ]|[ਕ-ਹ]|[ક-હ]|[କ-ହ]|[க-ஹ]|[క-హ]|[ಕ-ಹ]|[ക-ഹ])),
					after   => q(),
					replace => q(lh),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q((?:[-]|[bcdfghjklmnpqrstvwxyz]|[क-ह]|[ক-হ]|[ਕ-ਹ]|[ક-હ]|[କ-ହ]|[க-ஹ]|[క-హ]|[ಕ-ಹ]|[ക-ഹ])),
					after   => q(),
					replace => q(l̥),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q((?:[-]|[bcdfghjklmnpqrstvwxyz]|[क-ह]|[ক-হ]|[ਕ-ਹ]|[ક-હ]|[କ-ହ]|[க-ஹ]|[క-హ]|[ಕ-ಹ]|[ക-ഹ])),
					after   => q(),
					replace => q(ē),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q((?:[-]|[bcdfghjklmnpqrstvwxyz]|[क-ह]|[ক-হ]|[ਕ-ਹ]|[ક-હ]|[କ-ହ]|[க-ஹ]|[క-హ]|[ಕ-ಹ]|[ക-ഹ])),
					after   => q(),
					replace => q(ō),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q((?:[-]|[bcdfghjklmnpqrstvwxyz]|[क-ह]|[ক-হ]|[ਕ-ਹ]|[ક-હ]|[କ-ହ]|[க-ஹ]|[క-హ]|[ಕ-ಹ]|[ക-ഹ])),
					after   => q(),
					replace => q(ĕ),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q((?:[-]|[bcdfghjklmnpqrstvwxyz]|[क-ह]|[ক-হ]|[ਕ-ਹ]|[ક-હ]|[କ-ହ]|[க-ஹ]|[క-హ]|[ಕ-ಹ]|[ക-ഹ])),
					after   => q(),
					replace => q(ŏ),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q((?:[-]|[bcdfghjklmnpqrstvwxyz]|[क-ह]|[ক-হ]|[ਕ-ਹ]|[ક-હ]|[କ-ହ]|[க-ஹ]|[క-హ]|[ಕ-ಹ]|[ക-ഹ])),
					after   => q(),
					replace => q(e),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q((?:[-]|[bcdfghjklmnpqrstvwxyz]|[क-ह]|[ক-হ]|[ਕ-ਹ]|[ક-હ]|[କ-ହ]|[க-ஹ]|[క-హ]|[ಕ-ಹ]|[ക-ഹ])),
					after   => q(),
					replace => q(o),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ā),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ai),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(au),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ī),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(i),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ū),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(u),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(r̥̄),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(r̥),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(l̥̄),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(lh),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(l̥),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ē),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ō),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(a),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ĕ),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ŏ),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(e),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q('om),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(o),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(r̥),
					replace => q(n),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(l̥),
					replace => q(n),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(na),
					replace => q(n),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([kg]),
					replace => q(ṅ),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(ṅ),
					replace => q(ṅ),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([cj]),
					replace => q(n̄),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(ñ),
					replace => q(n̄),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([tdn]̣),
					replace => q(ṇ),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([tdn]),
					replace => q(n),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([pbm]),
					replace => q(m),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ylvshr]),
					replace => q(n),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ṁ),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(q),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḵẖ),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ġ),
					result  => q(),
					revisit => 1,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(z),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(f),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ṯ),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ẏ),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḻ),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ṉ),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ṅ),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ñ),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ṇ),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ṭh),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ṭ),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ṛh),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ṛ),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḍh),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḍ),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kh),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(k),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(gh),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(g),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ch),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(c),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(jh),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(j),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ny),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(tth),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ddh),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(th),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(t),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(dh),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(d),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(n),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ph),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(p),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(bh),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(b),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(m),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(y),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ṟ),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(r),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḷ),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(l),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(v),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ẇ),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(w),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(sh),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ss),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ṣ),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ś),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(s),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(h),
					result  => q(|),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q([--]),
					after   => q(),
					replace => q(\'),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q([-]),
					after   => q(),
					replace => q(\'),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ā),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ai),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(au),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ii),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ī),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(i),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ū),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(u),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(r̥̄),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(r̥a),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(r̥),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(l̥̄),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(lh),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(l̥),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ē),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ō),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(a),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ĕ),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ŏ),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(e),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(o),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q('ā),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q('ai),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q('au),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q('ī),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q('i),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q('ū),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q('u),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q('r̥̄),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q('r̥),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q('l̥̄),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q('l̥),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q('ē),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q('ō),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q('a),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q('ĕ),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q('ŏ),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q('e),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q('o),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q('ā),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q('ai),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q('au),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q('ī),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q('i),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q('ū),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q('u),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q('r̥̄),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q('r̥),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q('l̥̄),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q('l̥),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q('ē),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q('ō),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q('a),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q('ĕ),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q('ŏ),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q('e),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q('o),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([bcdfghjklmnpqrstvwxyz]),
					replace => q(),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(\'),
					replace => q(),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([]),
					replace => q(),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ʔ),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(1),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(2),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(3),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(4),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(5),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(6),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(7),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(8),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(9),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q('),
					result  => q(),
					revisit => 0,
				},
			]
		},
	] },
);

no Moo;

1;

# vim: tabstop=4
