package Locale::CLDR::Transformations::Any::Latin::Thailogical;
# This file auto generated from Data\common\transforms\ThaiLogical-Latin.xml
#	on Sun  4 Mar  1:00:42 pm GMT

use strict;
use warnings;
use version;

our $VERSION = version->declare('v0.32.0');

use v5.10.1;
use mro 'c3';
use utf8;
use if $^V ge v5.12.0, feature => 'unicode_strings';
use Types::Standard qw( Str Int HashRef ArrayRef CodeRef RegexpRef );
use Moo;

BEGIN {
	die "Transliteration requires Perl 5.18 or above"
		unless $^V ge v5.18.0;
}

no warnings 'experimental::regex_sets';
has 'transforms' => (
	is => 'ro',
	isa => ArrayRef,
	init_arg => undef,
	default => sub { [
		qr/(?^um:\G.)/,
		{
			type => 'transform',
			data => [
				{
					from => q(Any),
					to => q(lower),
				},
			],
		},
		{
			type => 'conversion',
			data => [
				{
					before  => q(),
					after   => q(),
					replace => q(z),
					result  => q(),
					revisit => 1,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(q),
					result  => q(),
					revisit => 1,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(j),
					result  => q(),
					revisit => 1,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(h),
					result  => q(),
					revisit => 1,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(g),
					result  => q(),
					revisit => 1,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(i),
					result  => q(ิ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ˌ),
					result  => q(ฺ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(«),
					result  => q(ๆ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(»),
					result  => q(๛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(๚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(9),
					result  => q(๙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(8),
					result  => q(๘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(7),
					result  => q(๗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(6),
					result  => q(๖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(5),
					result  => q(๕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(4),
					result  => q(๔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(3),
					result  => q(๓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(2),
					result  => q(๒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(1),
					result  => q(๑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(๐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(๏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(̊),
					result  => q(ํ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(๎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(̒),
					result  => q(์),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(̌),
					result  => q(๋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(́),
					result  => q(๊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(̂),
					result  => q(้),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(̀),
					result  => q(่),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(̆),
					result  => q(็),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ɨ),
					result  => q(ๅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ị),
					result  => q(ไ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ı),
					result  => q(ใ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(o),
					result  => q(โ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(æ),
					result  => q(แ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(e),
					result  => q(เ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(‡),
					result  => q(ฯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(u),
					result  => q(ุ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(u([^\p \{ ccc = 0 \} \p \{ ccc = above \}]*)̄),
					result  => q(ู),
					revisit => 2,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ū),
					result  => q(ู),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ụ),
					result  => q(ึ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ụ([^\p \{ ccc = 0 \} \p \{ ccc = above \}]*)̄),
					result  => q(ื),
					revisit => 2,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ụ̄),
					result  => q(ื),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(i([^\p \{ ccc = 0 \} \p \{ ccc = above \}]*)̄),
					result  => q(ี),
					revisit => 2,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ī),
					result  => q(ี),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(a),
					result  => q(ะ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(a([^\p \{ ccc = 0 \} \p \{ ccc = above \}]*)̉),
					result  => q(ำ),
					revisit => 2,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(a([^\p \{ ccc = 0 \} \p \{ ccc = above \}]*)̄),
					result  => q(า),
					revisit => 2,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ạ),
					result  => q(ั),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(s),
					result  => q(ซ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(x),
					result  => q(อ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(f),
					result  => q(ฟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(l),
					result  => q(ล),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḷ),
					result  => q(ฬ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(s([^\p \{ ccc = 0 \} \p \{ ccc = above \}]*)̄),
					result  => q(ส),
					revisit => 2,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(s̄ʹ),
					result  => q(ษ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ṣ([^\p \{ ccc = 0 \} \p \{ ccc = above \}]*)̄),
					result  => q(ศ),
					revisit => 2,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ṣ̄),
					result  => q(ศ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(w),
					result  => q(ว),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ł),
					result  => q(ฦ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(v),
					result  => q(ฤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(r),
					result  => q(ร),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(y),
					result  => q(ย),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(m),
					result  => q(ม),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(f([^\p \{ ccc = 0 \} \p \{ ccc = above \}]*)̄),
					result  => q(ฝ),
					revisit => 2,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(f̄),
					result  => q(ฝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(b),
					result  => q(บ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(d),
					result  => q(ด),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḍ),
					result  => q(ฎ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ỵ),
					result  => q(ญ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(n),
					result  => q(น),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ṇ),
					result  => q(ณ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ng),
					result  => q(ง),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(t),
					result  => q(ต),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(t̩),
					result  => q(ฏ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?:(?!(?:[̥]|[̣̄]))(?s:.))),
					replace => q(th),
					result  => q(ท),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([̥] (?:(?![̣̄])(?s:.))),
					replace => q(th),
					result  => q(ท),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ṭh),
					result  => q(ธ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(t̄h),
					result  => q(ถ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(tʹh),
					result  => q(ฒ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ṯh),
					result  => q(ฑ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ṭ̄h),
					result  => q(ฐ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(c),
					result  => q(จ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?:(?!(?:[̥]|[̣̄]))(?s:.))),
					replace => q(ch),
					result  => q(ช),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([̥] (?:(?![̣̄])(?s:.))),
					replace => q(ch),
					result  => q(ช),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(c̣h),
					result  => q(ฌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(c̄h),
					result  => q(ฉ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(p),
					result  => q(ป),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?:(?!(?:[̥]|[̣̄]))(?s:.))),
					replace => q(ph),
					result  => q(พ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([̥] (?:(?![̣̄])(?s:.))),
					replace => q(ph),
					result  => q(พ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(p̄h),
					result  => q(ผ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(p̣h),
					result  => q(ภ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(k),
					result  => q(ก),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?:(?!(?:[̥]|[̣̄]))(?s:.))),
					replace => q(kh),
					result  => q(ค),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([̥] (?:(?![̣̄])(?s:.))),
					replace => q(kh),
					result  => q(ค),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḳh),
					result  => q(ฆ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kʹh),
					result  => q(ฅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḳ̄h),
					result  => q(ฃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(k̄h),
					result  => q(ข),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḥ),
					result  => q(ฮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(h([^\p \{ ccc = 0 \} \p \{ ccc = above \}]*)̄),
					result  => q(ห),
					revisit => 2,
				},
			]
		},
	] },
);

no Moo;

1;

# vim: tabstop=4
