package Locale::CLDR::Transformations::Any::Cans::Latn;
# This file auto generated from Data\common\transforms\CanadianAboriginal-Latin.xml
#	on Sun  4 Mar  1:00:39 pm GMT

use strict;
use warnings;
use version;

our $VERSION = version->declare('v0.32.0');

use v5.10.1;
use mro 'c3';
use utf8;
use if $^V ge v5.12.0, feature => 'unicode_strings';
use Types::Standard qw( Str Int HashRef ArrayRef CodeRef RegexpRef );
use Moo;

BEGIN {
	die "Transliteration requires Perl 5.18 or above"
		unless $^V ge v5.18.0;
}

no warnings 'experimental::regex_sets';
has 'transforms' => (
	is => 'ro',
	isa => ArrayRef,
	init_arg => undef,
	default => sub { [
		qr/(?^um:\G.)/,
		{
			type => 'transform',
			data => [
			],
		},
		{
			type => 'conversion',
			data => [
				{
					before  => q(),
					after   => q(),
					replace => q(᙮),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᐦ),
					result  => q(h),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᐊ),
					result  => q(ha),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᐋ),
					result  => q(hâ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᐅ),
					result  => q(ho),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᐆ),
					result  => q(hô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᐃ),
					result  => q(hi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᐄ),
					result  => q(hî),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᐁ),
					result  => q(hê),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᕐ),
					result  => q(r),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᕋ),
					result  => q(ra),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᕌ),
					result  => q(râ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᕈ),
					result  => q(ro),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᕉ),
					result  => q(rô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᕆ),
					result  => q(ri),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᕇ),
					result  => q(rî),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᕂ),
					result  => q(rê),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᔾ),
					result  => q(y),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᔭ),
					result  => q(ya),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᔮ),
					result  => q(yâ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᔪ),
					result  => q(yo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᔫ),
					result  => q(yô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᔨ),
					result  => q(yi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᔩ),
					result  => q(yî),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᔦ),
					result  => q(yê),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᔅ),
					result  => q(s),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᓴ),
					result  => q(sa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᓵ),
					result  => q(sâ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᓱ),
					result  => q(so),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᓲ),
					result  => q(sô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᓯ),
					result  => q(si),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᓰ),
					result  => q(sî),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᓭ),
					result  => q(sê),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᓪ),
					result  => q(l),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᓚ),
					result  => q(la),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᓛ),
					result  => q(lâ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᓗ),
					result  => q(lo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᓘ),
					result  => q(lô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᓕ),
					result  => q(li),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᓖ),
					result  => q(lî),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᓓ),
					result  => q(lê),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᓐ),
					result  => q(n),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᓇ),
					result  => q(na),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᓈ),
					result  => q(nâ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᓄ),
					result  => q(no),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᓅ),
					result  => q(nô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᓂ),
					result  => q(ni),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᓃ),
					result  => q(nî),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᓀ),
					result  => q(nê),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᒻ),
					result  => q(m),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᒪ),
					result  => q(ma),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᒫ),
					result  => q(mâ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᒧ),
					result  => q(mo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᒨ),
					result  => q(mô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᒥ),
					result  => q(mi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᒦ),
					result  => q(mî),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᒣ),
					result  => q(mê),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᒡ),
					result  => q(c),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᒐ),
					result  => q(ca),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᒑ),
					result  => q(câ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᒍ),
					result  => q(co),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᒎ),
					result  => q(cô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᒋ),
					result  => q(ci),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᒌ),
					result  => q(cî),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᒉ),
					result  => q(cê),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᒃ),
					result  => q(k),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᒄ),
					result  => q(kw),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᑲ),
					result  => q(ka),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᑳ),
					result  => q(kâ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᑯ),
					result  => q(ko),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᑰ),
					result  => q(kô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᑭ),
					result  => q(ki),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᑮ),
					result  => q(kî),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᑫ),
					result  => q(kê),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᑦ),
					result  => q(t),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᑕ),
					result  => q(ta),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᑖ),
					result  => q(tâ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᑐ),
					result  => q(to),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᑑ),
					result  => q(tô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᑎ),
					result  => q(ti),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᑏ),
					result  => q(tî),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᑌ),
					result  => q(tê),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᑉ),
					result  => q(p),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᐸ),
					result  => q(pa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᐹ),
					result  => q(pâ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᐳ),
					result  => q(po),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᐴ),
					result  => q(pô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᐱ),
					result  => q(pi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᐲ),
					result  => q(pî),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᐯ),
					result  => q(pê),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᐤ),
					result  => q(w),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᐗ),
					result  => q(wa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᐙ),
					result  => q(wâ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᐒ),
					result  => q(wo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᐔ),
					result  => q(wô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᐎ),
					result  => q(wi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᐐ),
					result  => q(wî),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᐌ),
					result  => q(wê),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᔥ),
					result  => q(š),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᔖ),
					result  => q(ša),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᔕ),
					result  => q(šâ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᔔ),
					result  => q(šo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᔓ),
					result  => q(šô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᔒ),
					result  => q(ši),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᔑ),
					result  => q(šî),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᔐ),
					result  => q(šê),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᖮ),
					result  => q(th),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᖬ),
					result  => q(tha),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᖭ),
					result  => q(thâ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᖪ),
					result  => q(tho),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᖫ),
					result  => q(thô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᖨ),
					result  => q(thi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᖩ),
					result  => q(thî),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᖧ),
					result  => q(thê),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᕽ),
					result  => q(hk),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᕎ),
					result  => q(rwâ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᔹ),
					result  => q(ywa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᔻ),
					result  => q(ywâ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᔵ),
					result  => q(ywo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᔷ),
					result  => q(ywô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᔱ),
					result  => q(ywi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᔳ),
					result  => q(ywî),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᔯ),
					result  => q(ywê),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᔀ),
					result  => q(swa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᔂ),
					result  => q(swâ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᓼ),
					result  => q(swo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᓾ),
					result  => q(swô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᓸ),
					result  => q(swi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᓺ),
					result  => q(swî),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᓶ),
					result  => q(swê),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᓦ),
					result  => q(lwa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᓨ),
					result  => q(lwâ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᓢ),
					result  => q(lwo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᓤ),
					result  => q(lwô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᓞ),
					result  => q(lwi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᓠ),
					result  => q(lwî),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᓜ),
					result  => q(lwê),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᓋ),
					result  => q(nwa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᓍ),
					result  => q(nwâ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᓉ),
					result  => q(nwê),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᒶ),
					result  => q(mwa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᒸ),
					result  => q(mwâ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᒲ),
					result  => q(mwo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᒴ),
					result  => q(mwô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᒮ),
					result  => q(mwi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᒰ),
					result  => q(mwî),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᒬ),
					result  => q(mwê),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᒜ),
					result  => q(cwa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᒞ),
					result  => q(cwâ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᒘ),
					result  => q(cwo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᒚ),
					result  => q(cwô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᒔ),
					result  => q(cwi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᒖ),
					result  => q(cwî),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᒒ),
					result  => q(cwê),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᑾ),
					result  => q(kwa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᒀ),
					result  => q(kwâ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᑺ),
					result  => q(kwo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᑼ),
					result  => q(kwô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᑶ),
					result  => q(kwi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᑸ),
					result  => q(kwî),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᑴ),
					result  => q(kwê),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᑡ),
					result  => q(twa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᑣ),
					result  => q(twâ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᑝ),
					result  => q(two),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᑟ),
					result  => q(twô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᑙ),
					result  => q(twi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᑛ),
					result  => q(twî),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᑗ),
					result  => q(twê),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᑄ),
					result  => q(pwa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᑆ),
					result  => q(pwâ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᑀ),
					result  => q(pwo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᑂ),
					result  => q(pwô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᐼ),
					result  => q(pwi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᐾ),
					result  => q(pwî),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᐺ),
					result  => q(pwê),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᔡ),
					result  => q(šwa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᔣ),
					result  => q(šwâ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᔝ),
					result  => q(šwo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᔟ),
					result  => q(šwô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᔙ),
					result  => q(šwi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᔛ),
					result  => q(šwî),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᔗ),
					result  => q(šwê),
					revisit => 0,
				},
			]
		},
	] },
);

no Moo;

1;

# vim: tabstop=4
