package Locale::CLDR::Transformations::Any::Kana::Hira;
# This file auto generated from Data\common\transforms\Hiragana-Katakana.xml
#	on Sun  4 Mar  1:00:40 pm GMT

use strict;
use warnings;
use version;

our $VERSION = version->declare('v0.32.0');

use v5.10.1;
use mro 'c3';
use utf8;
use if $^V ge v5.12.0, feature => 'unicode_strings';
use Types::Standard qw( Str Int HashRef ArrayRef CodeRef RegexpRef );
use Moo;

BEGIN {
	die "Transliteration requires Perl 5.18 or above"
		unless $^V ge v5.18.0;
}

no warnings 'experimental::regex_sets';
has 'transforms' => (
	is => 'ro',
	isa => ArrayRef,
	init_arg => undef,
	default => sub { [
		qr/(?^um:\G.)/,
		{
			type => 'transform',
			data => [
				{
					from => q(Any),
					to => q(NFKC),
				},
			],
		},
		{
			type => 'conversion',
			data => [
				{
					before  => q(),
					after   => q(),
					replace => q({ー),
					result  => q(お),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q({ー),
					result  => q(え),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q({ー),
					result  => q(う),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q({ー),
					result  => q(い),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q({ー),
					result  => q(あ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ヶ),
					result  => q(け),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ヵ),
					result  => q(か),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ヾ),
					result  => q(ゞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ヽ),
					result  => q(ゝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ヴ),
					result  => q(ゔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ン),
					result  => q(ん),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ヲ),
					result  => q(を),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ヱ),
					result  => q(ゑ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ヰ),
					result  => q(ゐ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ワ),
					result  => q(わ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ヮ),
					result  => q(ゎ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ロ),
					result  => q(ろ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(レ),
					result  => q(れ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ル),
					result  => q(る),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(リ),
					result  => q(り),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ラ),
					result  => q(ら),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ヨ),
					result  => q(よ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ョ),
					result  => q(ょ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ユ),
					result  => q(ゆ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ュ),
					result  => q(ゅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ヤ),
					result  => q(や),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ャ),
					result  => q(ゃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(モ),
					result  => q(も),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(メ),
					result  => q(め),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ム),
					result  => q(む),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ミ),
					result  => q(み),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(マ),
					result  => q(ま),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ポ),
					result  => q(ぽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ボ),
					result  => q(ぼ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ホ),
					result  => q(ほ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ペ),
					result  => q(ぺ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ベ),
					result  => q(べ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ヘ),
					result  => q(へ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(プ),
					result  => q(ぷ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ブ),
					result  => q(ぶ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(フ),
					result  => q(ふ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ピ),
					result  => q(ぴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ビ),
					result  => q(び),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ヒ),
					result  => q(ひ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(パ),
					result  => q(ぱ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(バ),
					result  => q(ば),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ハ),
					result  => q(は),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ノ),
					result  => q(の),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ネ),
					result  => q(ね),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ヌ),
					result  => q(ぬ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ニ),
					result  => q(に),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ナ),
					result  => q(な),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ド),
					result  => q(ど),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ト),
					result  => q(と),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(デ),
					result  => q(で),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(テ),
					result  => q(て),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ヅ),
					result  => q(づ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ツ),
					result  => q(つ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ッ),
					result  => q(っ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ヂ),
					result  => q(ぢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(チ),
					result  => q(ち),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ダ),
					result  => q(だ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(タ),
					result  => q(た),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ゾ),
					result  => q(ぞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ソ),
					result  => q(そ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ゼ),
					result  => q(ぜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(セ),
					result  => q(せ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ズ),
					result  => q(ず),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ス),
					result  => q(す),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ジ),
					result  => q(じ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(シ),
					result  => q(し),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ザ),
					result  => q(ざ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(サ),
					result  => q(さ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ゴ),
					result  => q(ご),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(コ),
					result  => q(こ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ゲ),
					result  => q(げ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ケ),
					result  => q(け),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(グ),
					result  => q(ぐ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ク),
					result  => q(く),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ギ),
					result  => q(ぎ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(キ),
					result  => q(き),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ガ),
					result  => q(が),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(カ),
					result  => q(か),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(オ),
					result  => q(お),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ォ),
					result  => q(ぉ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(エ),
					result  => q(え),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ェ),
					result  => q(ぇ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ウ),
					result  => q(う),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ゥ),
					result  => q(ぅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(イ),
					result  => q(い),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ィ),
					result  => q(ぃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ア),
					result  => q(あ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ァ),
					result  => q(ぁ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ヺ),
					result  => q(を゙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ヹ),
					result  => q(ゑ゙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ヸ),
					result  => q(ゐ゙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ヷ),
					result  => q(わ゙),
					revisit => 0,
				},
			]
		},
	] },
);

no Moo;

1;

# vim: tabstop=4
