package Locale::CLDR::Transformations::Any::Thaa::Latn;
# This file auto generated from Data\common\transforms\Thaana-Latin.xml
#	on Sun  4 Mar  1:00:42 pm GMT

use strict;
use warnings;
use version;

our $VERSION = version->declare('v0.32.0');

use v5.10.1;
use mro 'c3';
use utf8;
use if $^V ge v5.12.0, feature => 'unicode_strings';
use Types::Standard qw( Str Int HashRef ArrayRef CodeRef RegexpRef );
use Moo;

BEGIN {
	die "Transliteration requires Perl 5.18 or above"
		unless $^V ge v5.18.0;
}

no warnings 'experimental::regex_sets';
has 'transforms' => (
	is => 'ro',
	isa => ArrayRef,
	init_arg => undef,
	default => sub { [
		qr/(?^um:\G.)/,
		{
			type => 'transform',
			data => [
			],
		},
		{
			type => 'conversion',
			data => [
				{
					before  => q(),
					after   => q(),
					replace => q(ް),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޯ),
					result  => q(ō),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޮ),
					result  => q(o),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޭ),
					result  => q(ē),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ެ),
					result  => q(e),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޫ),
					result  => q(ū),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ު),
					result  => q(u),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ީ),
					result  => q(ī),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ި),
					result  => q(i),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ާ),
					result  => q(ā),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ަ),
					result  => q(a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޤ),
					result  => q(q),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޣ),
					result  => q(ǧ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޢ),
					result  => q(ʿ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޠ),
					result  => q(t̤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޟ),
					result  => q(ḏ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޞ),
					result  => q(ṣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޝ),
					result  => q(š),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޛ),
					result  => q(dh),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޚ),
					result  => q(kh),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޙ),
					result  => q(ḥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޘ),
					result  => q(tt),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޔ),
					result  => q(y),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޕ),
					result  => q(p),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޓ),
					result  => q(ṭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޒ),
					result  => q(z),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޗ),
					result  => q(č),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޖ),
					result  => q(j),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޑ),
					result  => q(ḍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ސ),
					result  => q(s),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޏ),
					result  => q(ñ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ގ),
					result  => q(g),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ލ),
					result  => q(l),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ތ),
					result  => q(t),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ދ),
					result  => q(d),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ފ),
					result  => q(f),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(މ),
					result  => q(m),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ވ),
					result  => q(v),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(އ),
					result  => q(‘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ކ),
					result  => q(k),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޅ),
					result  => q(ḷ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ބ),
					result  => q(b),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ރ),
					result  => q(r),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ނ),
					result  => q(n),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ށ),
					result  => q(š),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ހ),
					result  => q(h),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޔް),
					result  => q(y),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޕް),
					result  => q(p),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޓް),
					result  => q(ṭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޒް),
					result  => q(z),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޗް),
					result  => q(č),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޖް),
					result  => q(j),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޑް),
					result  => q(ḍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ސް),
					result  => q(s),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޏް),
					result  => q(ñ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ގް),
					result  => q(g),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ލް),
					result  => q(l),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ތް),
					result  => q(t),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ދް),
					result  => q(d),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ފް),
					result  => q(f),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(މް),
					result  => q(m),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ވް),
					result  => q(v),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(އް),
					result  => q(‘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ކް),
					result  => q(k),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޅް),
					result  => q(ḷ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ބް),
					result  => q(b),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ރް),
					result  => q(r),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ން),
					result  => q(n),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ށް),
					result  => q(š),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ހް),
					result  => q(h),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޤް),
					result  => q(q),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޣް),
					result  => q(ǧ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޢް),
					result  => q(ʿ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޠް),
					result  => q(t̤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޟް),
					result  => q(ḏ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޞް),
					result  => q(ṣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޝް),
					result  => q(š),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޛް),
					result  => q(dh),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޚް),
					result  => q(kh),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޙް),
					result  => q(ḥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޘް),
					result  => q(tt),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޔޯ),
					result  => q(yō),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޕޯ),
					result  => q(pō),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޓޯ),
					result  => q(ṭō),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޒޯ),
					result  => q(zō),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޗޯ),
					result  => q(čō),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޖޯ),
					result  => q(jō),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޑޯ),
					result  => q(ḍō),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ސޯ),
					result  => q(sō),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޏޯ),
					result  => q(ñō),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ގޯ),
					result  => q(gō),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ލޯ),
					result  => q(lō),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ތޯ),
					result  => q(tō),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ދޯ),
					result  => q(dō),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ފޯ),
					result  => q(fō),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(މޯ),
					result  => q(mō),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ވޯ),
					result  => q(vō),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(އޯ),
					result  => q(‘ō),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ކޯ),
					result  => q(kō),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޅޯ),
					result  => q(ḷō),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ބޯ),
					result  => q(bō),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ރޯ),
					result  => q(rō),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ނޯ),
					result  => q(nō),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ށޯ),
					result  => q(šō),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ހޯ),
					result  => q(hō),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޤޯ),
					result  => q(qō),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޣޯ),
					result  => q(ǧō),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޢޯ),
					result  => q(ʿō),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޠޯ),
					result  => q(t̤ō),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޟޯ),
					result  => q(ḏō),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޞޯ),
					result  => q(ṣō),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޝޯ),
					result  => q(šō),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޛޯ),
					result  => q(dhō),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޚޯ),
					result  => q(khō),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޙޯ),
					result  => q(ḥō),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޘޯ),
					result  => q(ttō),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޔޮ),
					result  => q(yo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޕޮ),
					result  => q(po),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޓޮ),
					result  => q(ṭo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޒޮ),
					result  => q(zo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޗޮ),
					result  => q(čo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޖޮ),
					result  => q(jo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޑޮ),
					result  => q(ḍo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ސޮ),
					result  => q(so),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޏޮ),
					result  => q(ño),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ގޮ),
					result  => q(go),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ލޮ),
					result  => q(lo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ތޮ),
					result  => q(to),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ދޮ),
					result  => q(do),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ފޮ),
					result  => q(fo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(މޮ),
					result  => q(mo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ވޮ),
					result  => q(vo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(އޮ),
					result  => q(‘o),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ކޮ),
					result  => q(ko),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޅޮ),
					result  => q(ḷo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ބޮ),
					result  => q(bo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ރޮ),
					result  => q(ro),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ނޮ),
					result  => q(no),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ށޮ),
					result  => q(šo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ހޮ),
					result  => q(ho),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޤޮ),
					result  => q(qo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޣޮ),
					result  => q(ǧo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޢޮ),
					result  => q(ʿo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޠޮ),
					result  => q(t̤o),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޟޮ),
					result  => q(ḏo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޞޮ),
					result  => q(ṣo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޝޮ),
					result  => q(šo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޛޮ),
					result  => q(dho),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޚޮ),
					result  => q(kho),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޙޮ),
					result  => q(ḥo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޘޮ),
					result  => q(tto),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޔޭ),
					result  => q(yē),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޕޭ),
					result  => q(pē),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޓޭ),
					result  => q(ṭē),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޒޭ),
					result  => q(zē),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޗޭ),
					result  => q(čē),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޖޭ),
					result  => q(jē),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޑޭ),
					result  => q(ḍē),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ސޭ),
					result  => q(sē),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޏޭ),
					result  => q(ñē),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ގޭ),
					result  => q(gē),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ލޭ),
					result  => q(lē),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ތޭ),
					result  => q(tē),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ދޭ),
					result  => q(dē),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ފޭ),
					result  => q(fē),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(މޭ),
					result  => q(mē),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ވޭ),
					result  => q(vē),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(އޭ),
					result  => q(‘ē),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ކޭ),
					result  => q(kē),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޅޭ),
					result  => q(ḷē),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ބޭ),
					result  => q(bē),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ރޭ),
					result  => q(rē),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ނޭ),
					result  => q(nē),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ށޭ),
					result  => q(šē),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ހޭ),
					result  => q(hē),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޤޭ),
					result  => q(qē),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޣޭ),
					result  => q(ǧē),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޢޭ),
					result  => q(ʿē),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޠޭ),
					result  => q(t̤ē),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޟޭ),
					result  => q(ḏē),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޞޭ),
					result  => q(ṣē),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޝޭ),
					result  => q(šē),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޛޭ),
					result  => q(dhē),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޚޭ),
					result  => q(khē),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޙޭ),
					result  => q(ḥē),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޘޭ),
					result  => q(ttē),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޔެ),
					result  => q(ye),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޕެ),
					result  => q(pe),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޓެ),
					result  => q(ṭe),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޒެ),
					result  => q(ze),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޗެ),
					result  => q(če),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޖެ),
					result  => q(je),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޑެ),
					result  => q(ḍe),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ސެ),
					result  => q(se),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޏެ),
					result  => q(ñe),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ގެ),
					result  => q(ge),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ލެ),
					result  => q(le),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ތެ),
					result  => q(te),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ދެ),
					result  => q(de),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ފެ),
					result  => q(fe),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(މެ),
					result  => q(me),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ވެ),
					result  => q(ve),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(އެ),
					result  => q(‘e),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ކެ),
					result  => q(ke),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޅެ),
					result  => q(ḷe),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ބެ),
					result  => q(be),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ރެ),
					result  => q(re),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ނެ),
					result  => q(ne),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ށެ),
					result  => q(še),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ހެ),
					result  => q(he),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޤެ),
					result  => q(qe),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޣެ),
					result  => q(ǧe),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޢެ),
					result  => q(ʿe),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޠެ),
					result  => q(t̤e),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޟެ),
					result  => q(ḏe),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޞެ),
					result  => q(ṣe),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޝެ),
					result  => q(še),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޛެ),
					result  => q(dhe),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޚެ),
					result  => q(khe),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޙެ),
					result  => q(ḥe),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޘެ),
					result  => q(tte),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޔޫ),
					result  => q(yū),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޕޫ),
					result  => q(pū),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޓޫ),
					result  => q(ṭū),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޒޫ),
					result  => q(zū),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޗޫ),
					result  => q(čū),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޖޫ),
					result  => q(jū),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޑޫ),
					result  => q(ḍū),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ސޫ),
					result  => q(sū),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޏޫ),
					result  => q(ñū),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ގޫ),
					result  => q(gū),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ލޫ),
					result  => q(lū),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ތޫ),
					result  => q(tū),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ދޫ),
					result  => q(dū),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ފޫ),
					result  => q(fū),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(މޫ),
					result  => q(mū),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ވޫ),
					result  => q(vū),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(އޫ),
					result  => q(‘ū),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ކޫ),
					result  => q(kū),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޅޫ),
					result  => q(ḷū),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ބޫ),
					result  => q(bū),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ރޫ),
					result  => q(rū),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ނޫ),
					result  => q(nū),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ށޫ),
					result  => q(šū),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ހޫ),
					result  => q(hū),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޤޫ),
					result  => q(qū),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޣޫ),
					result  => q(ǧū),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޢޫ),
					result  => q(ʿū),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޠޫ),
					result  => q(t̤ū),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޟޫ),
					result  => q(ḏū),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޞޫ),
					result  => q(ṣū),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޝޫ),
					result  => q(šū),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޛޫ),
					result  => q(dhū),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޚޫ),
					result  => q(khū),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޙޫ),
					result  => q(ḥū),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޘޫ),
					result  => q(ttū),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޔު),
					result  => q(yu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޕު),
					result  => q(pu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޓު),
					result  => q(ṭu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޒު),
					result  => q(zu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޗު),
					result  => q(ču),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޖު),
					result  => q(ju),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޑު),
					result  => q(ḍu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ސު),
					result  => q(su),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޏު),
					result  => q(ñu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ގު),
					result  => q(gu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ލު),
					result  => q(lu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ތު),
					result  => q(tu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ދު),
					result  => q(du),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ފު),
					result  => q(fu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(މު),
					result  => q(mu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ވު),
					result  => q(vu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(އު),
					result  => q(‘u),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ކު),
					result  => q(ku),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޅު),
					result  => q(ḷu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ބު),
					result  => q(bu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ރު),
					result  => q(ru),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ނު),
					result  => q(nu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ށު),
					result  => q(šu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ހު),
					result  => q(hu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޤު),
					result  => q(qu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޣު),
					result  => q(ǧu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޢު),
					result  => q(ʿu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޠު),
					result  => q(t̤u),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޟު),
					result  => q(ḏu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޞު),
					result  => q(ṣu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޝު),
					result  => q(šu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޛު),
					result  => q(dhu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޚު),
					result  => q(khu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޙު),
					result  => q(ḥu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޘު),
					result  => q(ttu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޔީ),
					result  => q(yī),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޕީ),
					result  => q(pī),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޓީ),
					result  => q(ṭī),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޒީ),
					result  => q(zī),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޗީ),
					result  => q(čī),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޖީ),
					result  => q(jī),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޑީ),
					result  => q(ḍī),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ސީ),
					result  => q(sī),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޏީ),
					result  => q(ñī),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ގީ),
					result  => q(gī),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ލީ),
					result  => q(lī),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ތީ),
					result  => q(tī),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ދީ),
					result  => q(dī),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ފީ),
					result  => q(fī),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(މީ),
					result  => q(mī),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ވީ),
					result  => q(vī),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(އީ),
					result  => q(‘ī),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ކީ),
					result  => q(kī),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޅީ),
					result  => q(ḷī),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ބީ),
					result  => q(bī),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ރީ),
					result  => q(rī),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ނީ),
					result  => q(nī),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ށީ),
					result  => q(šī),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ހީ),
					result  => q(hī),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޤީ),
					result  => q(qī),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޣީ),
					result  => q(ǧī),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޢީ),
					result  => q(ʿī),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޠީ),
					result  => q(t̤ī),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޟީ),
					result  => q(ḏī),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޞީ),
					result  => q(ṣī),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޝީ),
					result  => q(šī),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޛީ),
					result  => q(dhī),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޚީ),
					result  => q(khī),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޙީ),
					result  => q(ḥī),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޘީ),
					result  => q(ttī),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޔި),
					result  => q(yi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޕި),
					result  => q(pi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޓި),
					result  => q(ṭi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޒި),
					result  => q(zi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޗި),
					result  => q(či),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޖި),
					result  => q(ji),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޑި),
					result  => q(ḍi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ސި),
					result  => q(si),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޏި),
					result  => q(ñi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ގި),
					result  => q(gi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ލި),
					result  => q(li),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ތި),
					result  => q(ti),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ދި),
					result  => q(di),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ފި),
					result  => q(fi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(މި),
					result  => q(mi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ވި),
					result  => q(vi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(އި),
					result  => q(‘i),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ކި),
					result  => q(ki),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޅި),
					result  => q(ḷi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ބި),
					result  => q(bi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ރި),
					result  => q(ri),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ނި),
					result  => q(ni),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ށި),
					result  => q(ši),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ހި),
					result  => q(hi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޤި),
					result  => q(qi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޣި),
					result  => q(ǧi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޢި),
					result  => q(ʿi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޠި),
					result  => q(t̤i),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޟި),
					result  => q(ḏi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޞި),
					result  => q(ṣi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޝި),
					result  => q(ši),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޛި),
					result  => q(dhi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޚި),
					result  => q(khi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޙި),
					result  => q(ḥi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޘި),
					result  => q(tti),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޔާ),
					result  => q(yā),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޕާ),
					result  => q(pā),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޓާ),
					result  => q(ṭā),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޒާ),
					result  => q(zā),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޗާ),
					result  => q(čā),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޖާ),
					result  => q(jā),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޑާ),
					result  => q(ḍā),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ސާ),
					result  => q(sā),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޏާ),
					result  => q(ñā),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ގާ),
					result  => q(gā),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ލާ),
					result  => q(lā),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ތާ),
					result  => q(tā),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ދާ),
					result  => q(dā),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ފާ),
					result  => q(fā),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(މާ),
					result  => q(mā),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ވާ),
					result  => q(vā),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(އާ),
					result  => q(‘ā),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ކާ),
					result  => q(kā),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޅާ),
					result  => q(ḷā),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ބާ),
					result  => q(bā),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ރާ),
					result  => q(rā),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ނާ),
					result  => q(nā),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ށާ),
					result  => q(šā),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ހާ),
					result  => q(hā),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޤާ),
					result  => q(qā),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޣާ),
					result  => q(ǧā),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޢާ),
					result  => q(ʿā),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޠާ),
					result  => q(t̤ā),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޟާ),
					result  => q(ḏā),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޞާ),
					result  => q(ṣā),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޝާ),
					result  => q(šā),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޛާ),
					result  => q(dhā),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޚާ),
					result  => q(khā),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޙާ),
					result  => q(ḥā),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޘާ),
					result  => q(ttā),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޔަ),
					result  => q(ya),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޕަ),
					result  => q(pa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޓަ),
					result  => q(ṭa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޒަ),
					result  => q(za),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޗަ),
					result  => q(ča),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޖަ),
					result  => q(ja),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޑަ),
					result  => q(ḍa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ސަ),
					result  => q(sa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޏަ),
					result  => q(ña),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ގަ),
					result  => q(ga),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ލަ),
					result  => q(la),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ތަ),
					result  => q(ta),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ދަ),
					result  => q(da),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ފަ),
					result  => q(fa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(މަ),
					result  => q(ma),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ވަ),
					result  => q(va),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(އަ),
					result  => q(‘a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ކަ),
					result  => q(ka),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޅަ),
					result  => q(ḷa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ބަ),
					result  => q(ba),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ރަ),
					result  => q(ra),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ނަ),
					result  => q(na),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ށަ),
					result  => q(ša),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ހަ),
					result  => q(ha),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޤަ),
					result  => q(qa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޣަ),
					result  => q(ǧa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޢަ),
					result  => q(ʿa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޠަ),
					result  => q(t̤a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޟަ),
					result  => q(ḏa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޞަ),
					result  => q(ṣa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޝަ),
					result  => q(ša),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޛަ),
					result  => q(dha),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޚަ),
					result  => q(kha),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޙަ),
					result  => q(ḥa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ޘަ),
					result  => q(tta),
					revisit => 0,
				},
			]
		},
	] },
);

no Moo;

1;

# vim: tabstop=4
