package Locale::CLDR::Transformations::Any::Latn::Cans;
# This file auto generated from Data\common\transforms\CanadianAboriginal-Latin.xml
#	on Sun  4 Mar  1:00:39 pm GMT

use strict;
use warnings;
use version;

our $VERSION = version->declare('v0.32.0');

use v5.10.1;
use mro 'c3';
use utf8;
use if $^V ge v5.12.0, feature => 'unicode_strings';
use Types::Standard qw( Str Int HashRef ArrayRef CodeRef RegexpRef );
use Moo;

BEGIN {
	die "Transliteration requires Perl 5.18 or above"
		unless $^V ge v5.18.0;
}

no warnings 'experimental::regex_sets';
has 'transforms' => (
	is => 'ro',
	isa => ArrayRef,
	init_arg => undef,
	default => sub { [
		qr/(?^um:\G.)/,
		{
			type => 'transform',
			data => [
			],
		},
		{
			type => 'conversion',
			data => [
				{
					before  => q(),
					after   => q(),
					replace => q(šwê),
					result  => q(ᔗ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(šwî),
					result  => q(ᔛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(šwi),
					result  => q(ᔙ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(šwô),
					result  => q(ᔟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(šwo),
					result  => q(ᔝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(šwâ),
					result  => q(ᔣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(šwa),
					result  => q(ᔡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pwê),
					result  => q(ᐺ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pwî),
					result  => q(ᐾ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pwi),
					result  => q(ᐼ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pwô),
					result  => q(ᑂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pwo),
					result  => q(ᑀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pwâ),
					result  => q(ᑆ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pwa),
					result  => q(ᑄ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(twê),
					result  => q(ᑗ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(twî),
					result  => q(ᑛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(twi),
					result  => q(ᑙ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(twô),
					result  => q(ᑟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(two),
					result  => q(ᑝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(twâ),
					result  => q(ᑣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(twa),
					result  => q(ᑡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kwê),
					result  => q(ᑴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kwî),
					result  => q(ᑸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kwi),
					result  => q(ᑶ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kwô),
					result  => q(ᑼ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kwo),
					result  => q(ᑺ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kwâ),
					result  => q(ᒀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kwa),
					result  => q(ᑾ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(cwê),
					result  => q(ᒒ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(cwî),
					result  => q(ᒖ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(cwi),
					result  => q(ᒔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(cwô),
					result  => q(ᒚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(cwo),
					result  => q(ᒘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(cwâ),
					result  => q(ᒞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(cwa),
					result  => q(ᒜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(mwê),
					result  => q(ᒬ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(mwî),
					result  => q(ᒰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(mwi),
					result  => q(ᒮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(mwô),
					result  => q(ᒴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(mwo),
					result  => q(ᒲ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(mwâ),
					result  => q(ᒸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(mwa),
					result  => q(ᒶ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(nwê),
					result  => q(ᓉ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(nwâ),
					result  => q(ᓍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(nwa),
					result  => q(ᓋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(lwê),
					result  => q(ᓜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(lwî),
					result  => q(ᓠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(lwi),
					result  => q(ᓞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(lwô),
					result  => q(ᓤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(lwo),
					result  => q(ᓢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(lwâ),
					result  => q(ᓨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(lwa),
					result  => q(ᓦ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(swê),
					result  => q(ᓶ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(swî),
					result  => q(ᓺ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(swi),
					result  => q(ᓸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(swô),
					result  => q(ᓾ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(swo),
					result  => q(ᓼ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(swâ),
					result  => q(ᔂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(swa),
					result  => q(ᔀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ywê),
					result  => q(ᔯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ywî),
					result  => q(ᔳ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ywi),
					result  => q(ᔱ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ywô),
					result  => q(ᔷ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ywo),
					result  => q(ᔵ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ywâ),
					result  => q(ᔻ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ywa),
					result  => q(ᔹ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(rwâ),
					result  => q(ᕎ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(hk),
					result  => q(ᕽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(thê),
					result  => q(ᖧ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(thî),
					result  => q(ᖩ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(thi),
					result  => q(ᖨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(thô),
					result  => q(ᖫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(tho),
					result  => q(ᖪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(thâ),
					result  => q(ᖭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(tha),
					result  => q(ᖬ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(th),
					result  => q(ᖮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(šê),
					result  => q(ᔐ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(šî),
					result  => q(ᔑ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ši),
					result  => q(ᔒ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(šô),
					result  => q(ᔓ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(šo),
					result  => q(ᔔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(šâ),
					result  => q(ᔕ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ša),
					result  => q(ᔖ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(š),
					result  => q(ᔥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(wê),
					result  => q(ᐌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(wî),
					result  => q(ᐐ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(wi),
					result  => q(ᐎ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(wô),
					result  => q(ᐔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(wo),
					result  => q(ᐒ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(wâ),
					result  => q(ᐙ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(wa),
					result  => q(ᐗ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(w),
					result  => q(ᐤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pê),
					result  => q(ᐯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pî),
					result  => q(ᐲ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pi),
					result  => q(ᐱ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pô),
					result  => q(ᐴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(po),
					result  => q(ᐳ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pâ),
					result  => q(ᐹ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pa),
					result  => q(ᐸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(p),
					result  => q(ᑉ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(tê),
					result  => q(ᑌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(tî),
					result  => q(ᑏ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ti),
					result  => q(ᑎ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(tô),
					result  => q(ᑑ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(to),
					result  => q(ᑐ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(tâ),
					result  => q(ᑖ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ta),
					result  => q(ᑕ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(t),
					result  => q(ᑦ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kê),
					result  => q(ᑫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kî),
					result  => q(ᑮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ki),
					result  => q(ᑭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kô),
					result  => q(ᑰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ko),
					result  => q(ᑯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kâ),
					result  => q(ᑳ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ka),
					result  => q(ᑲ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kw),
					result  => q(ᒄ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(k),
					result  => q(ᒃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(cê),
					result  => q(ᒉ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(cî),
					result  => q(ᒌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ci),
					result  => q(ᒋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(cô),
					result  => q(ᒎ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(co),
					result  => q(ᒍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(câ),
					result  => q(ᒑ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ca),
					result  => q(ᒐ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(c),
					result  => q(ᒡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(mê),
					result  => q(ᒣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(mî),
					result  => q(ᒦ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(mi),
					result  => q(ᒥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(mô),
					result  => q(ᒨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(mo),
					result  => q(ᒧ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(mâ),
					result  => q(ᒫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ma),
					result  => q(ᒪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(m),
					result  => q(ᒻ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(nê),
					result  => q(ᓀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(nî),
					result  => q(ᓃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ni),
					result  => q(ᓂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(nô),
					result  => q(ᓅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(no),
					result  => q(ᓄ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(nâ),
					result  => q(ᓈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(na),
					result  => q(ᓇ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(n),
					result  => q(ᓐ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(lê),
					result  => q(ᓓ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(lî),
					result  => q(ᓖ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(li),
					result  => q(ᓕ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(lô),
					result  => q(ᓘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(lo),
					result  => q(ᓗ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(lâ),
					result  => q(ᓛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(la),
					result  => q(ᓚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(l),
					result  => q(ᓪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(sê),
					result  => q(ᓭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(sî),
					result  => q(ᓰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(si),
					result  => q(ᓯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(sô),
					result  => q(ᓲ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(so),
					result  => q(ᓱ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(sâ),
					result  => q(ᓵ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(sa),
					result  => q(ᓴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(s),
					result  => q(ᔅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(yê),
					result  => q(ᔦ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(yî),
					result  => q(ᔩ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(yi),
					result  => q(ᔨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(yô),
					result  => q(ᔫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(yo),
					result  => q(ᔪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(yâ),
					result  => q(ᔮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ya),
					result  => q(ᔭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(y),
					result  => q(ᔾ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(rê),
					result  => q(ᕂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(rî),
					result  => q(ᕇ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ri),
					result  => q(ᕆ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(rô),
					result  => q(ᕉ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ro),
					result  => q(ᕈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(râ),
					result  => q(ᕌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ra),
					result  => q(ᕋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(r),
					result  => q(ᕐ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(hê),
					result  => q(ᐁ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(hî),
					result  => q(ᐄ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(hi),
					result  => q(ᐃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(hô),
					result  => q(ᐆ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ho),
					result  => q(ᐅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(hâ),
					result  => q(ᐋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ha),
					result  => q(ᐊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(h),
					result  => q(ᐦ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(᙮),
					revisit => 0,
				},
			]
		},
	] },
);

no Moo;

1;

# vim: tabstop=4
